@@ -1,15 +1,13 @@
-# ================= Effect Size Standard Errors ============
-
-# se.mean2 
+# se.mean2 =========================================================
 #' Computes the standard error for a 2-group mean difference
 #' 
 #' 
 #' @description
 #' This function can be used to compute the standard error of a 
-#' 2-group mean difference using the two estimated means, estimated 
+#' 2-group mean difference using the estimated means, estimated 
 #' standard deviations, and sample sizes. The effect size estimate 
 #' and standard error output from this function can be used as input
-#' in the \link[vcmeta]{meta.ave.gen},  \link[vcmeta]{meta.lc.gen}, 
+#' in the \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen}, 
 #' and \link[vcmeta]{meta.lm.gen} functions in applications where 
 #' compatible mean differences from a combination of 2-group
 #' and paired-samples experiments are used in the meta-analysis. 
@@ -19,8 +17,8 @@
 #' @param    m2		estimated mean for group 2 
 #' @param    sd1	estimated standard deviation for group 1
 #' @param    sd2	estimated standard deviation for group 2
-#' @param    n1		group 1 sample size
-#' @param    n2		group 2 sample size
+#' @param    n1		sample size for group 1
+#' @param    n2		sample size for group 2
 #' 
 #' 
 #' @return
@@ -52,17 +50,17 @@ se.mean2 <- function(m1, m2, sd1, sd2, n1, n2) {
 }
 
 
-# se.mean.ps
+# se.mean.ps =========================================================
 #' Computes the standard error for a paired-samples mean difference
 #' 
 #' 
 #' @description
 #' This function can be used to compute the standard error of a 
-#' paired-samples mean difference using the two estimated means, 
+#' paired-samples mean difference using the estimated means, 
 #  estimated standard deviations, estimated Pearson correlation, 
 #' and sample size. The effect size estimate and standard error 
 #' output from this function can be used as input in the
-#' \link[vcmeta]{meta.ave.gen}, #' \link[vcmeta]{meta.lc.gen}, 
+#' \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen}, 
 #' and \link[vcmeta]{meta.lm.gen} functions in applications where 
 #' compatible mean differences from a combination of 2-group
 #' and paired-samples experiments are used in the meta-analysis. 
@@ -104,28 +102,32 @@ se.mean.ps <- function(m1, m2, sd1, sd2, cor, n) {
 }
 
 
-# se.stdmean2 		
+# se.stdmean2 =========================================================		
 #' Computes the standard error for a 2-group standardized mean difference
 #' 
 #' 
 #' @description
-#' Use the square root average variance standardizer (stdzr = 0) for 2-group
-#' experimental designs. Use the square root weighted variance standardizer
-#' (stdzr = 3) for 2-group nonexperimental designs with simple random sampling.
-#' The single-group standardizers (stdzr = 1 and stdzr = 2) can be used with
-#' either 2-group experimental or nonexperimental designs. The effect size 
-#' estimate and standard error output from this function can be used as input
-#' in the \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} 
-#' functions in applications where compatible standardized mean differences from a 
-#' combination of 2-group and paired-samples experiments are used in the meta-analysis. 
+#' This function computes the standard error of a 2-group standardized
+#' mean difference using the sample sizes and the estimated means
+#  and standard deviations. Use the square root average variance
+#' standardizer (stdzr = 0) for 2-group experimental designs. Use the 
+#' square root weighted variance standardizer (stdzr = 3) for 2-group 
+#' nonexperimental designs with simple random sampling. The single-group 
+#' standardizers (stdzr = 1 and stdzr = 2) can be used with either 
+#' 2-group experimental or nonexperimental designs. The effect size 
+#' estimate and standard error output from this function can be used as 
+#' input in the \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen},
+#' and \link[vcmeta]{meta.lm.gen} functions in applications where compatible
+#' standardized mean differences from a combination of 2-group and 
+#' paired-samples experiments are used in the meta-analysis. 
 #'
 #' 
-#' @param    m1		  sample mean for group 1 
-#' @param    m2		  sample mean for group 2 
-#' @param    sd1		sample standard deviation for group 1
-#' @param    sd2		sample standard deviation for group 2
-#' @param    n1		  group 1 sample size
-#' @param    n2		  group 2 sample size
+#' @param    m1		  estimated mean for group 1 
+#' @param    m2		  estimated mean for group 2 
+#' @param    sd1		estimated standard deviation for group 1
+#' @param    sd2		estimated standard deviation for group 2
+#' @param    n1		  sample size for group 1
+#' @param    n2		  sample size for group 2
 #' @param stdzr
 #' * set to 0 for square root average variance standardizer 
 #' * set to 1 for group 1 SD standardizer 
@@ -182,23 +184,25 @@ se.stdmean2 <- function(m1, m2, sd1, sd2, n1, n2, stdzr) {
 }
 
 
-# se.stdmean.ps 		
+# se.stdmean.ps =========================================================		
 #' Computes the standard error for a paired-samples standardized mean difference
 #' 
 #'
 #' @description
-#' The effect size estimate and standard error output from this function can be used 
-#' as input in the \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen}, and 
-#' \link[vcmeta]{meta.lm.gen} functions in applications where compatible standardized 
-#' mean differences from a combination of 2-group and paired-samples experiments are 
-#' used in the meta-analysis. 
+#' This function computes the standard error of a paired-samples standardized
+#' mean difference using the sample size and estimated means, standard 
+#' deviations, and estimated correlation. The effect size estimate and standard error
+#' output from this function can be used as input in the \link[vcmeta]{meta.ave.gen},
+#' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions in 
+#' applications where compatible standardized mean differences from a combination
+#' of 2-group and paired-samples experiments are used in the meta-analysis. 
 #' 
 #' 
-#' @param    m1		sample mean for measurement 1 
-#' @param    m2		sample mean for measurement 2 
-#' @param    sd1	sample standard deviation for measurement 1
-#' @param    sd2	sample standard deviation for measurement 2
-#' @param    cor	sample correlation for measurements 1 and 2
+#' @param    m1		estimated mean for measurement 1 
+#' @param    m2		estimated mean for measurement 2 
+#' @param    sd1	estimated standard deviation for measurement 1
+#' @param    sd2	estimated standard deviation for measurement 2
+#' @param    cor	estimated correlation for measurements 1 and 2
 #' @param    n		sample size
 #' @param stdzr
 #' * set to 0 for square root average variance standardizer 
@@ -251,7 +255,7 @@ se.stdmean.ps <- function(m1, m2, sd1, sd2, cor, n, stdzr) {
 }
 
 
-# se.cor
+# se.cor =========================================================
 #' Computes the standard error for a Pearson or partial correlation 
 #' 
 #'
@@ -263,11 +267,11 @@ se.stdmean.ps <- function(m1, m2, sd1, sd2, cor, n, stdzr) {
 #' as input in the \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen},
 #' and \link[vcmeta]{meta.lm.gen} functions in applications where a 
 #' combination of different types of correlations are used in the
-# meta-analysis. 
+#' meta-analysis. 
 #' 
 #' 
 #' @param    cor	estimated Pearson or partial correlation  
-#' @param    s		number of control variables (0 for Pearson)  
+#' @param    s		number of control variables (set to 0 for Pearson)  
 #' @param    n		sample size
 #'   
 #'   
@@ -299,7 +303,7 @@ se.cor <- function(cor, s, n) {
 }
 
 
-# se.spear
+# se.spear =========================================================
 #' Computes the standard error for a Spearman correlation 
 #' 
 #' 
@@ -344,7 +348,7 @@ se.spear <- function(cor, n) {
 }
 
 
-# se.semipart
+# se.semipart =========================================================
 #' Computes the standard error for a semipartial correlation 
 #' 
 #'
@@ -389,12 +393,13 @@ se.semipartial <- function(cor, r2, n) {
  return(out)
 }
 
-# se.pbcor
+
+# se.pbcor =========================================================
 #' Computes the standard error for a point-biserial correlation 
 #' 
 #'
 #' @description
-#' The function computes a point-biserial correlation and its standard 
+#' This function computes a point-biserial correlation and its standard 
 #' error for two types of point-biserial correlations in 2-group designs
 #' using the estimated means, estimated standard deviations, and samples
 #' sizes. One type of point-biserial correlation uses an unweighted average
@@ -413,8 +418,8 @@ se.semipartial <- function(cor, r2, n) {
 #' @param    m2		estimated mean for group 2 
 #' @param    sd1	estimated standard deviation for group 1
 #' @param    sd2	estimated standard deviation for group 2
-#' @param    n1		group 1 sample size
-#' @param    n2		group 2 sample size
+#' @param    n1		sample size for group 1
+#' @param    n2		sample size for group 2
 #' @param    type		
 #' * set to 1 for weighted variance average
 #' * set to 2 for unweighted variance average
@@ -464,7 +469,7 @@ se.pbcor <- function(m1, m2, sd1, sd2, n1, n2, type) {
 }
 
 
-# se.odds
+# se.odds =========================================================
 #' Computes the standard error for a log odds ratio 
 #' 
 #'
@@ -482,8 +487,8 @@ se.pbcor <- function(m1, m2, sd1, sd2, n1, n2, type) {
 #' 
 #' @param    f1		number of participants who have the outcome of interest in group 1 
 #' @param    f2		number of participants who have the outcome of interest in group 2   
-#' @param    n1		group 1 sample size
-#' @param    n2		group 2 sample size
+#' @param    n1		sample size for group 1
+#' @param    n2		sample size for group 2 
 #' 
 #' 
 #' @return
@@ -515,16 +520,16 @@ se.odds <- function(f1, n1, f2, n2) {
 }
 
 
-# se.meanratio2
+# se.meanratio2 =========================================================
 #' Computes the standard error for a 2-group log mean ratio
 #' 
 #' 
 #' @description
 #' This function can be used to compute the standard error of a 
-#' 2-group mean ratio using the two estimated means, estimated standard
-#' deviations, and sample sizes. The effect size estimate and standard 
+#' 2-group log mean ratio using the estimated means, estimated standard
+#' deviations, and sample sizes. The log mean estimate and standard 
 #' error output from this function can be used as input in the
-#' \link[vcmeta]{meta.ave.gen},  \link[vcmeta]{meta.lc.gen}, and
+#' \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen}, and
 #' link[vcmeta]{meta.lm.gen} functions in application where compatible
 #' mean ratios from a combination of 2-group and paired-samples experiments
 #' are used in the meta-analysis.
@@ -534,15 +539,14 @@ se.odds <- function(f1, n1, f2, n2) {
 #' @param    m2		estimated mean for group 2 
 #' @param    sd1	estimated standard deviation for group 1
 #' @param    sd2	estimated standard deviation for group 2
-#' @param    n1		group 1 sample size
-#' @param    n2		group 2 sample size
+#' @param    n1		sample size for group 1
+#' @param    n2		sample size for group 2
 #' 
 #' 
 #' @return
 #' Returns a one-row matrix:
 #' * Estimate - estimate of log mean ratio
 #' * SE - standard error
-#' @return
 #'  
 #' @examples
 #' se.meanratio2(21.9, 16.1, 3.82, 3.21, 40, 40)
@@ -569,15 +573,15 @@ se.meanratio2 <- function(m1, m2, sd1, sd2, n1, n2) {
 }
 
 
-# se.meanratio.ps
+# se.meanratio.ps =========================================================
 #' Computes the standard error for a paired-samples log mean ratio
 #' 
 #' 
 #' @description
 #' This function can be used to compute the standard error of a 
-#' paired-samples mean ratio using the estimated eans, estimated
+#' paired-samples log mean ratio using the estimated means, estimated
 #  standard deviations, estimated Pearson correlation, and sample 
-#' size. The effect size estimate and standard error output from
+#' size. The log-mean estimate and standard error output from
 #' this function can be used as input in the \link[vcmeta]{meta.ave.gen}, 
 #' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions in 
 #' application where compatible mean ratios from a combination of 2-group
@@ -596,7 +600,6 @@ se.meanratio2 <- function(m1, m2, sd1, sd2, n1, n2) {
 #' Returns a one-row matrix:
 #' * Estimate - estimate of log mean ratio
 #' * SE - standard error
-#' @return
 #'  
 #' @examples
 #' se.meanratio.ps(21.9, 16.1, 3.82, 3.21, .748, 40)
@@ -624,14 +627,14 @@ se.meanratio.ps <- function(m1, m2, sd1, sd2, cor, n) {
 }
 
 
-# se.slope
+# se.slope =========================================================
 #' Computes a slope and standard error
 #' 
 #'
 #' @description 
 #' This function can be used to compute a slope and its standard error
-#' for a simple linear regression model using the estimated Pearson
-#' correlation and the estimated standard deviations of response and 
+#' for a simple linear regression model (random-x model) using the estimated 
+#' Pearson correlation and the estimated standard deviations of response and 
 #' predictor variables. This function is useful in a meta-analysis of 
 #' slopes of a simple linear regression model where some studies report
 #' the Pearson correlation but not the slope.
@@ -671,14 +674,14 @@ se.slope <- function(cor, sdy, sdx, n) {
 }
 
 
-# se.prop2 
+# se.prop2 ========================================================= 
 #' Computes the Agresti-Caffo estimate and standard error for a 2-group
 #' proportion difference
 #' 
 #' 
 #' @description
 #' This function can be used to compute the standard error of a 
-#' 2-group proportion difference using the two sample proportions and sample
+#' 2-group proportion difference using the frequency counts and sample
 #' sizes. The effect size estimate and standard error output from this
 #' function can be used as input in the \link[vcmeta]{meta.ave.gen}, 
 #' \link[vcmeta]{meta.lc.gen}, and \link[vcmeta]{meta.lm.gen} functions in 
@@ -688,8 +691,8 @@ se.slope <- function(cor, sdy, sdx, n) {
 #' 
 #' @param    f1   number of participants in group 1 who have the outcome
 #' @param    f2	  number of participants in group 2 who have the outcome
-#' @param    n1	  group 1 sample size
-#' @param    n2	  group 2 sample size
+#' @param    n1	  sample size for group 1
+#' @param    n2	  sample size for group 2
 #' 
 #' 
 #' @return
@@ -723,9 +726,9 @@ se.prop2 <- function(f1, f2, n1, n2) {
 }
 
 
-# se.prop.ps 
-#' Computes the Bonett-Price estimate and standard error for a paired-samples
-#' proportion difference
+# se.prop.ps =========================================================
+#' Computes the Bonett-Price estimate and standard error for a 
+#' paired-samples proportion difference
 #' 
 #' 
 #' @description
@@ -759,7 +762,7 @@ se.prop2 <- function(f1, f2, n1, n2) {
 #' 
 #' 
 #' @references
-#' \insertRef{Agresti2000}{vcmeta}
+#' \insertRef{Bonett2012}{vcmeta}
 #'
 #'
 #' @export
@@ -775,3 +778,319 @@ se.prop.ps <- function(f00, f01, f10, f11) {
  return(out)
 }
 
+
+# se.ave.mean2.dep ============================================================
+#' Computes the standard error for the average of 2-group mean differences from 
+#' two parallel measurement response variables in the same sample 
+#'                       
+#' 
+#' @description
+#' In a study that reports a 2-group mean difference for two response
+#' variables that satisfy the conditions of parallel measurments, this function
+#' can be used to compute the standard error of the average of the two mean 
+#' differences using the two estimated means, estimated standard deviations, 
+#' estimated within-group correlation between the two response variables, and 
+#' the two sample sizes. The average mean difference and standard error output 
+#' from this function can then be used as input in the
+#' \link[vcmeta]{meta.ave.gen}, \link[vcmeta]{meta.lc.gen}, and 
+#' \link[vcmeta]{meta.lm.gen} functions in a meta-analysis where some studies
+#' have used one of the two parallel response variables and other studies have
+#' used the other parallel response variable. 
+#' 
+#' 
+#' @param    m1A	   estimated mean for variable A in group 1 
+#' @param    m2A	   estimated mean for variable A in group 2 
+#' @param    sd1A	   estimated standard deviation for variable A in group 1
+#' @param    sd2A	   estimated standard deviation for variable A in group 2
+#' @param    m1B	   estimated mean for variable B in group 1 
+#' @param    m2B	   estimated mean for variable B in group 2 
+#' @param    sd1B	   estimated standard deviation for variable B in group 1
+#' @param    sd2B	   estimated standard deviation for variable B in group 2
+#' @param    rAB	   estimated within-group correlation between variables A and B
+#' @param    n1		   sample size for group 1
+#' @param    n2		   sample size for group 2
+#' 
+#' 
+#' @return
+#' Returns a one-row matrix:
+#' * Estimate - estimate of average mean difference
+#' * SE - standard error 
+#' * VAR(A) - variance of mean difference for variable A
+#' * VAR(B) - variance of mean difference for variable B
+#' * COV(A,B) - covariance of mean differences for variables A and B
+#' 
+#'  
+#' @examples
+#' se.ave.mean2.dep(21.9, 16.1, 3.82, 3.21, 24.8, 17.1, 3.57, 3.64, .785, 40, 40)
+#'
+#' # Should return:
+#' #      Estimate        SE    VAR(A)    VAR(B)  COV(A,B)
+#' # [1,]     6.75 0.7526878 0.6224125 0.6498625 0.4969403
+#' 
+#' 
+#' @export
+se.ave.mean2.dep <- function(m1A, m2A, sd1A, sd2A, m1B, m2B, sd1B, sd2B, rAB, n1, n2) {
+  m1 <- (m1A + m1B)/2
+  m2 <- (m2A + m2B)/2
+  est <- m1 - m2
+  v1 <- sd1A^2/n1 + sd2A^2/n2 
+  v2 <- sd1B^2/n1 + sd2B^2/n2
+  cov <- rAB*sd1A*sd1B/n1 + rAB*sd2A*sd2B/n2
+  se <- sqrt((v1 + v2 + 2*cov)/4)
+  out <- t(c(est, se, v1, v2, cov))
+  colnames(out) <- c("Estimate", "SE", "VAR(A)", "VAR(B)", "COV(A,B)")
+  return(out)
+}
+
+
+# se.ave.cor.over =============================================================
+#' Computes the standard error for the average of two Pearson correlations with 
+#' one variable in common that have been estimated from the same sample 
+#'     
+#' 
+#' @description
+#' In a study that reports the sample size and three correlations (cor12, cor13, 
+#' and cor23 where variable 1 is called the "overlapping" variable), and 
+#' variables 2 and 3 are different measurements of the same attribute, this 
+#' function can be used to compute the average of cor12 and cor13 and its 
+#' standard error. The average correlation and the standard error from this 
+#' function can be used as input in the \link[vcmeta]{meta.ave.gen} function
+#' in a meta-analysis where some studies have reported cor12 and other studies
+#' have reported cor13. 
+#' 
+#' 
+#' @param    cor12	estimated correlation between variables 1 and 2 
+#' @param    cor13	estimated correlation between variables 1 and 3 
+#' @param    cor23	estimated correlation between variables 2 and 3
+#' @param    n		  sample size
+#' 
+#' 
+#' @return
+#' Returns a two-row matrix. The first row gives results for the average 
+#' correlation and the second row gives the results with a Fisher
+#' transformation. The columns are:
+#' * Estimate - estimated average of cor12 and cor13
+#' * SE - standard error 
+#' * VAR(cor12) - variance of cor12 
+#' * VAR(cor13) - variance of cor13
+#' * COV(cor12,cor13) - covariance of cor12 and cor13
+#' 
+#'  
+#' @examples
+#' se.ave.cor.over(.462, .518, .755, 100)
+#'
+#' # Should return:
+#' #               Estimate         SE  VAR(cor12) VAR(cor13) COV(cor12,cor13)
+#' # Correlation  0.4900000 0.07087351 0.006378045 0.00551907      0.004097553
+#' # Fisher       0.5360603 0.09326690 0.010309278 0.01030928      0.007119936
+#'
+#'
+#' @export
+se.ave.cor.over <- function(cor12, cor13, cor23, n) {
+  est1 <- (cor12 + cor13)/2
+  cov1 <- ((cor23 - cor12*cor13/2)*(1 - cor12^2 - cor13^2 - cor23^2) + cor23^3)/(n - 3)
+  v1 <- (1 - cor12^2)^2/(n - 3)
+  v2 <- (1 - cor13^2)^2/(n - 3)
+  se1 <- sqrt((v1 + v2 + 2*cov1)/4)
+  est2 <- log((1 + est1)/(1 - est1))/2 
+  se2 <- se1/(1 - est1^2)
+  cov2 <- cov1/((1 - cor12^2)*(1 - cor13^2))
+  v1.z <- 1/(n - 3)
+  v2.z <- 1/(n - 3)
+  out1 <- t(c(est1, se1, v1, v2, cov1))
+  out2 <- t(c(est2, se2, v1.z, v2.z, cov2))
+  out <- rbind(out1, out2)
+  colnames(out) <- c("Estimate", "SE", "VAR(cor12)", "VAR(cor13)", "COV(cor12,cor13)")
+  rownames(out) <- c("Correlation", "Fisher")
+  return(out)
+}
+
+
+# se.ave.cor.nonover ==========================================================
+#' Computes the standard error for the average of two Pearson correlations with 
+#' no variables in common that have been estimated from the same sample 
+#'
+#' 
+#' @description
+#' In a study that reports the sample size and six correlations (cor12, cor34,
+#' (cor13, cor14, cor23, and cor24) where variables 1 and 3 are different 
+#' measurements of the same attribute and variables 2 and 4 are different 
+#' measurements of the same attribute, this function can be used to compute the 
+#' average of cor12 and cor34 and its standard error. Note that cor12 and cor34
+#' have no variable in common (i.e., no "overlapping" variable). The average 
+#' correlation and the standard error from this function can be used as 
+#' input in the \link[vcmeta]{meta.ave.gen} function in a meta-analysis where
+#' some studies have reported cor12 and other studies have reported cor34. 
+#' 
+#' 
+#' @param    cor12	  estimated correlation between variables 1 and 2 
+#' @param    cor34	  estimated correlation between variables 3 and 4 
+#' @param    cor13	  estimated correlation between variables 1 and 3
+#' @param    cor14	  estimated correlation between variables 1 and 4
+#' @param    cor23	  estimated correlation between variables 2 and 3
+#' @param    cor24	  estimated correlation between variables 2 and 4
+#' @param    n		    sample size
+#' 
+#' 
+#' @return
+#' Returns a two-row matrix. The first row gives results for the average 
+#' correlation and the second row gives the results with a Fisher
+#' transformation. The columns are:
+#' * Estimate - estimated average of cor12 and cor34
+#' * SE - standard error 
+#' * VAR(cor12) - variance of cor12 
+#' * VAR(cor34) - variance of cor34
+#' * COV(cor12,cor34) - covariance of cor12 and cor34
+#' 
+#'  
+#' @examples
+#' se.ave.cor.nonover(.357, .398, .755, .331, .347, .821, 100)
+#'
+#' # Should return:
+#' #             Estimate         SE VAR(cor12)  VAR(cor34) COV(cor12,cor34)
+#' # Correlation 0.377500 0.07768887 0.00784892 0.007301895      0.004495714
+#' # Fisher      0.397141 0.09059993 0.01030928 0.010309278      0.006122153
+#'
+#'
+#' @export
+se.ave.cor.nonover <- function(cor12, cor34, cor13, cor14, cor23, cor24, n) {
+  est1 <- (cor12 + cor34)/2
+  c1 <- (cor12*cor34)*(cor13^2 + cor14^2 + cor23^2 + cor24^2)/2 + cor13*cor24 + cor14*cor23
+  c2 <- (cor12*cor13*cor14 + cor12*cor23*cor24 + cor13*cor23*cor34 + cor14*cor24*cor34)
+  cov1 <- (c1 - c2)/(n - 3)
+  v1 <- (1 - cor12^2)^2/(n - 3)
+  v2 <- (1 - cor34^2)^2/(n - 3)
+  se1 <- sqrt((v1 + v2 + 2*cov1)/4)
+  est2 <- log((1 + est1)/(1 - est1))/2 
+  se2 <- se1/(1 - est1^2)
+  cov2 <- cov1/((1 - cor12^2)*(1 - cor34^2))
+  v1.z <- 1/(n - 3)
+  v2.z <- 1/(n - 3)
+  out1 <- t(c(est1, se1, v1, v2, cov1))
+  out2 <- t(c(est2, se2, v1.z, v2.z, cov2))
+  out <- rbind(out1, out2)
+  colnames(out) <- c("Estimate", "SE", "VAR(cor12)", "VAR(cor34)", "COV(cor12,cor34)")
+  rownames(out) <- c("Correlation", "Fisher")
+  return(out)
+}
+
+
+#  se.tetra ==================================================================
+#' Computes the standard error for a tetrachoric correlation approximation  
+#'
+#'
+#' @description
+#' This function can be used to compute an estimate of a tetrachoric 
+#' correlation approximation and its standard error using the frequency counts
+#' from a 2 x 2 contingency table for two artifically dichotomous variables.
+#' A tetrachoric approximation could be compatible with a Pearson correlation
+#' in a meta-analysis. The tetrachoric approximation and the standard error 
+#' from this function can be used as input in the \link[vcmeta]{meta.ave.gen} 
+#' function in a meta-analysis where some studies have reported Pearson 
+#' correlations between quantitative variables x and y and other studies have
+#' reported a 2 x 2 contingency table for dichotomous measurements of variables
+#' x and y. 
+#'
+#'
+#' @param   f00    number of participants with y = 0 and x = 0
+#' @param   f01    number of participants with y = 0 and x = 1
+#' @param   f10    number of participants with y = 1 and x = 0
+#' @param   f11    number of participants with y = 1 and x = 1
+#'
+#'
+#' @references
+#' \insertRef{Bonett2005}{vcmeta}
+#'
+#'
+#' @return
+#' Returns a 1-row matrix. The columns are:
+#' * Estimate - estimate of tetrachoric approximation
+#' * SE - standard error
+#'
+#'
+#' @examples
+#' se.tetra(46, 15, 54, 85)
+#'
+#' # Should return:
+#' #       Estimate         SE 
+#' # [1,] 0.5135167 0.09358336
+#'
+#'
+#' @export
+se.tetra <- function(f00, f01, f10, f11) {
+ n <- f00 + f01 + f10 + f11
+ or <- (f11 + .5)*(f00 + .5)/((f01 + .5)*(f10 + .5))
+ r1 <- (f00 + f01 + 1)/(n + 2)
+ r2 <- (f10 + f11 + 1)/(n + 2)
+ c1 <- (f00 + f10 + 1)/(n + 2)
+ c2 <- (f01 + f11 + 1)/(n + 2)
+ pmin <- min(c1, c2, r1, r2)
+ c <- (1 - abs(r1 - c1)/5 - (.5 - pmin)^2)/2
+ lor <- log(or)
+ se.lor <- sqrt(1/(f00 + .5) + 1/(f01 + .5) + 1/(f10 + .5) + 1/(f11 + .5))
+ tetra <- cos(3.14159/(1 + or^c))
+ k <- (3.14159*c*or^c)*sin(3.14159/(1 + or^c))/(1 + or^c)^2
+ se <- k*se.lor
+ out <- t(c(tetra, se))
+ colnames(out) <- c("Estimate", "SE")
+ return(out)
+}
+
+
+#  se.biphi ==================================================================
+#' Computes the standard error for a biserial-phi correlation  
+#'
+#'
+#' @description
+#' This function can be used to compute an estimate of a biserial-phi  
+#' correlation and its standard error using the frequency counts from a 2 x 2
+#' contingency table where one variable is naturally dichotomous and the other
+#' variable is artifically dichotomous. A biserial-phi correlation could be 
+#' compatible with a point-biserial correlation in a meta-analysis. The 
+#' biserial-phi estimate and the standard error from this function can be used 
+#' as input in the \link[vcmeta]{meta.ave.gen} function in a meta-analysis 
+#' where a point-biserial correlation has been obtained in some studies and
+#' a biserial-phi correlation has been obtained in other studies.  
+#'
+#'
+#' @param   f1     number of participants in group 1 who have the attribute
+#' @param   f2     number of participants in group 2 who have the attribute
+#' @param   n1     sample size for group 1
+#' @param   n2     sample size for group 2
+#'
+#'
+#' @return
+#' Returns a 1-row matrix. The columns are:
+#' * Estimate - estimate of biserial-phi correlation 
+#' * SE - standard error
+#'
+#'
+#' @examples
+#' se.biphi(34, 22, 50, 50)
+#'
+#' # Should return:
+#' #       Estimate        SE 
+#' # [1,]   0.27539 0.1074594
+#'
+#'
+#' @export
+se.biphi <- function(f1, f2, n1, n2) {
+ if (f1 > n1) {stop("f cannot be greater than n")}
+ if (f2 > n2) {stop("f cannot be greater than n")}
+ f00 <- f1
+ f10 <- n1 - f1
+ f01 <- f2
+ f11 <- n2 - f2
+ p1 <- n1/(n1 + n2)
+ p2 <- n2/(n1 + n2)
+ or <- (f11 + .5)*(f00 + .5)/((f01 + .5)*(f10 + .5))
+ lor <- log(or)
+ se.lor <- sqrt(1/(f00 + .5) + 1/(f01 + .5) + 1/(f10 + .5) + 1/(f11 + .5))
+ c <- 2.89/(p1*p2)
+ biphi <- lor/sqrt(lor^2 + c)
+ se.biphi <- sqrt(c^2/(lor^2 + c)^3)*se.lor
+ out <- t(c(biphi, se.biphi))
+ colnames(out) <- c("Estimate", "SE")
+ return(out)
+}
+
